==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/web/kotlin/inputs/GetAppServiceEnvironmentAseCustomDnsSuffixConfigurationPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.web.kotlin.inputs

import com.pulumi.azurenative.web.inputs.GetAppServiceEnvironmentAseCustomDnsSuffixConfigurationPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property name Name of the App Service Environment.
 * @property resourceGroupName Name of the resource group to which the resource belongs.
 */
public data class GetAppServiceEnvironmentAseCustomDnsSuffixConfigurationPlainArgs(
    public val name: String,
    public val resourceGroupName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.web.inputs.GetAppServiceEnvironmentAseCustomDnsSuffixConfigurationPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.web.inputs.GetAppServiceEnvironmentAseCustomDnsSuffixConfigurationPlainArgs =
        com.pulumi.azurenative.web.inputs.GetAppServiceEnvironmentAseCustomDnsSuffixConfigurationPlainArgs.builder()
            .name(name.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetAppServiceEnvironmentAseCustomDnsSuffixConfigurationPlainArgs].
 */
@PulumiTagMarker
public class GetAppServiceEnvironmentAseCustomDnsSuffixConfigurationPlainArgsBuilder internal
constructor() {
    private var name: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value Name of the App Service Environment.
     */
    @JvmName("qaiopuyjmpgsrlas")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.name = mapped
    }

    /**
     * @param value Name of the resource group to which the resource belongs.
     */
    @JvmName("mfpcllihqelddsdg")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): GetAppServiceEnvironmentAseCustomDnsSuffixConfigurationPlainArgs =
        GetAppServiceEnvironmentAseCustomDnsSuffixConfigurationPlainArgs(
            name = name ?: throw PulumiNullFieldException("name"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/web/kotlin/inputs/GetAppServiceEnvironmentAseCustomDnsSuffixConfigurationPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.web.kotlin.inputs

import com.pulumi.azurenative.web.inputs.GetAppServiceEnvironmentAseCustomDnsSuffixConfigurationPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property name Name of the App Service Environment.
 * @property resourceGroupName Name of the resource group to which the resource belongs.
 */
public data class GetAppServiceEnvironmentAseCustomDnsSuffixConfigurationPlainArgs(
    public val name: String,
    public val resourceGroupName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.web.inputs.GetAppServiceEnvironmentAseCustomDnsSuffixConfigurationPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.web.inputs.GetAppServiceEnvironmentAseCustomDnsSuffixConfigurationPlainArgs =
        com.pulumi.azurenative.web.inputs.GetAppServiceEnvironmentAseCustomDnsSuffixConfigurationPlainArgs.builder()
            .name(name.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetAppServiceEnvironmentAseCustomDnsSuffixConfigurationPlainArgs].
 */
@PulumiTagMarker
public class GetAppServiceEnvironmentAseCustomDnsSuffixConfigurationPlainArgsBuilder internal
constructor() {
    private var name: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value Name of the App Service Environment.
     */
    @JvmName("pujlhjblvvbrukcb")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.name = mapped
    }

    /**
     * @param value Name of the resource group to which the resource belongs.
     */
    @JvmName("tvhyhqxxeagiodbe")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): GetAppServiceEnvironmentAseCustomDnsSuffixConfigurationPlainArgs =
        GetAppServiceEnvironmentAseCustomDnsSuffixConfigurationPlainArgs(
            name = name ?: throw PulumiNullFieldException("name"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        )
}
